using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using AmazonWrapper.Amazon.ECSWebservice;

public partial class Default2 : System.Web.UI.Page
{
	private DataTable searchResult = new DataTable();
	private string subscriptionId = ConfigurationManager.AppSettings["Amazon.Webservice.SubscriptionId"].ToString();
	private string associateId = ConfigurationManager.AppSettings["Amazon.Associates.ID"].ToString();
	private string browseNodeId;
	private int indexId;
	private string category;

	protected void Page_Load(object sender, EventArgs e)
	{
		// If the page is loading for the first time, set the grid current page index to 0
		if (!Page.IsPostBack)
		{
			dgrdBrowser.CurrentPageIndex = 0;
		}
		// Request required parameters from the querystring
		try
		{
			browseNodeId = Request.QueryString["browsenode"];
			indexId = int.Parse(Request.QueryString["indexid"]);
			category = Request.QueryString["catName"];
			Page.Title = "DNK Amazon Associates Webstore :: Browsing :: " + category;

			// Fetch the result and display the result set
			BindSearchResult();
		}
		catch
		{
			lblErrMsg.Text = "An error occured while processing your request. Please try again later.";
		}
	}

	public void BindSearchResult()
	{
		searchResult.Columns.Add(new DataColumn("Title", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ASIN", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ReleaseDate", typeof(string)));
		searchResult.Columns.Add(new DataColumn("Availability", typeof(string)));
		searchResult.Columns.Add(new DataColumn("ListPrice", typeof(string)));
		searchResult.Columns.Add(new DataColumn("SmallImage", typeof(string)));
		searchResult.Columns.Add(new DataColumn("AmazonPrice", typeof(string)));
		searchResult.Columns.Add(new DataColumn("Savings", typeof(string)));
		searchResult.Columns.Add(new DataColumn("DetailPageURL", typeof(string)));
		SearchIndex _index = (SearchIndex)indexId;
		Browse(browseNodeId, "1", _index);
	}
	private void Browse(string nodeId, string pageNumber, SearchIndex index)
	{
		SearchRequest req = new SearchRequest();

		req.SubscriptionId = subscriptionId;
		req.AssociateTag = associateId;
			 
		req.BrowseNode = nodeId;
		req.ItemPage = pageNumber;
		req.SearchIndex = index;

		Items items = req.Search(true);

		if (items != null)
		{
			dgrdBrowser.VirtualItemCount = Convert.ToInt32(items.TotalResults);
			double _savings;
			double _listPrice;
			double _salesPrice;
			//totalBrowseItemsLabel.Text = items.TotalResults.ToString();
			//categoryBrowseLabel.Text = nodeId;
			//currentBrowsePageLabel.Text = pageNumber;
			//totalBrowsePagesLabel.Text = items.TotalPages.ToString();

			Item[] itemArray = items.Item;
			if (itemArray != null)
			{
				searchResult.Rows.Clear();

				foreach (Item item in itemArray)
				{
					DataRow row = searchResult.NewRow();

					if (item.Offers != null)
					{
						Offer[] offerArray = item.Offers.Offer;
						if (offerArray != null)
						{
							if (offerArray[0].OfferListing != null)
							{
								if (offerArray[0].OfferListing[0].Price != null)
									row["AmazonPrice"] = offerArray[0].OfferListing[0].Price.FormattedPrice;
								if (offerArray[0].OfferListing[0].Availability != null)
									row["Availability"] = offerArray[0].OfferListing[0].Availability;
							}
						}
					}

					if (item.ItemAttributes.ListPrice != null)
						row["ListPrice"] = item.ItemAttributes.ListPrice.FormattedPrice;

					if (row["AmazonPrice"].ToString() != string.Empty)
					{
						if (row["AmazonPrice"].ToString() == "Too low to display")
							row["AmazonPrice"] = "Price available at checkout";

						try
						{
							_listPrice = double.Parse(item.ItemAttributes.ListPrice.FormattedPrice.Replace("$", "").Trim());
							_salesPrice = double.Parse(row["AmazonPrice"].ToString().Replace("$", "").Trim());
							_savings = ((_listPrice - _salesPrice) / (_listPrice) * 100);
							row["Savings"] = _savings.ToString("##.##") + "%";
						}
						catch
						{
							row["Savings"] = "N/A";
						}

						if (item.ItemAttributes.Title != null)
							row["Title"] = item.ItemAttributes.Title;

						if (item.ASIN != null)
							row["ASIN"] = item.ASIN;

						if (item.ItemAttributes.ReleaseDate != null)
							row["ReleaseDate"] = item.ItemAttributes.ReleaseDate;

						if (item.SmallImage != null)
							row["SmallImage"] = item.SmallImage.URL;
						else
							row["SmallImage"] = "noimage.gif";

						if (item.DetailPageURL != null)
							row["DetailPageURL"] = "ProductDetails.aspx?asin=" + item.ASIN;
						//row["DetailPageURL"] = item.DetailPageURL;

						searchResult.Rows.Add(row);					
						DataView dv = new DataView(searchResult);
						dgrdBrowser.DataSource = dv;
						dgrdBrowser.DataBind();

					}

					if (searchResult.Rows.Count < 1)
					{
						lblSearchInfo.Text = "There are no products available in this category";
					}
					else
					{
						lblSearchInfo.Text = items.TotalResults.ToString() + " items found in " + category + " (Displaying: page " + pageNumber + " of " + items.TotalPages.ToString() + " )";
					}
				}
			}
		}
	}
	public void dgrdBrowser_PageIndexChanged(object source, System.Web.UI.WebControls.DataGridPageChangedEventArgs e)
	{
		dgrdBrowser.CurrentPageIndex = e.NewPageIndex;
		SearchIndex index = (SearchIndex)indexId;
		Browse(browseNodeId, (e.NewPageIndex + 1).ToString(), index);
	}
}
